@@ -1,38 +1,44 @@
-# Copyright (c) 2005, 2006 Allan Saddi <allan@saddi.com>
-# All rights reserved.
-#
-# Redistribution and use in source and binary forms, with or without
-# modification, are permitted provided that the following conditions
-# are met:
-# 1. Redistributions of source code must retain the above copyright
-#    notice, this list of conditions and the following disclaimer.
-# 2. Redistributions in binary form must reproduce the above copyright
-#    notice, this list of conditions and the following disclaimer in the
-#    documentation and/or other materials provided with the distribution.
-#
-# THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
-# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
-# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
-# ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
-# FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
-# DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
-# OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
-# HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
-# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
-# OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
-# SUCH DAMAGE.
-#
-# $Id$
-
 """
+.. highlight:: python
+   :linenothreshold: 5
+
+.. highlight:: bash
+   :linenothreshold: 5
+
 fcgi - a FastCGI/WSGI gateway.
 
-For more information about FastCGI, see <http://www.fastcgi.com/>.
+:copyright: Copyright (c) 2005, 2006 Allan Saddi <allan@saddi.com>
+  All rights reserved.
+:license:
+
+ Redistribution and use in source and binary forms, with or without
+ modification, are permitted provided that the following conditions
+ are met:
+
+ 1. Redistributions of source code must retain the above copyright
+    notice, this list of conditions and the following disclaimer.
+ 2. Redistributions in binary form must reproduce the above copyright
+    notice, this list of conditions and the following disclaimer in the
+    documentation and/or other materials provided with the distribution.
+
+ THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS **AS IS** AND
+ ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
+ FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
+ DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
+ OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
+ HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
+ LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
+ OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
+ SUCH DAMAGE.
+
+For more information about FastCGI, see http://www.fastcgi.com/.
 
 For more information about the Web Server Gateway Interface, see
-<http://www.python.org/peps/pep-0333.html>.
+http://www.python.org/peps/pep-0333.html.
 
-Example usage:
+Example usage::
 
   #!/usr/bin/env python
   from myapplication import app # Assume app is your WSGI application object
@@ -51,20 +57,21 @@ __version__ = '$Revision$'
 
 import os
 
-from flup.server.fcgi_base import BaseFCGIServer, \
+from .fcgi_base import BaseFCGIServer, FCGI_RESPONDER, \
      FCGI_MAX_CONNS, FCGI_MAX_REQS, FCGI_MPXS_CONNS
-from flup.server.preforkserver import PreforkServer
+from .preforkserver import PreforkServer
 
 __all__ = ['WSGIServer']
 
 class WSGIServer(BaseFCGIServer, PreforkServer):
     """
     FastCGI server that supports the Web Server Gateway Interface. See
-    <http://www.python.org/peps/pep-0333.html>.
+    http://www.python.org/peps/pep-0333.html.
     """
     def __init__(self, application, environ=None,
                  bindAddress=None, umask=None, multiplexed=False,
-                 debug=True, **kw):
+                 debug=False, roles=(FCGI_RESPONDER,), forceCGI=False,
+                 timeout=None, **kw):
         """
         environ, if present, must be a dictionary-like object. Its
         contents will be copied into application's environ. Useful
@@ -86,12 +93,14 @@ class WSGIServer(BaseFCGIServer, PreforkServer):
                                 bindAddress=bindAddress,
                                 umask=umask,
                                 multiplexed=multiplexed,
-                                debug=debug)
+                                debug=debug,
+                                roles=roles,
+                                forceCGI=forceCGI)
         for key in ('multithreaded', 'multiprocess', 'jobClass', 'jobArgs'):
-            if kw.has_key(key):
+            if key in kw:
                 del kw[key]
         PreforkServer.__init__(self, jobClass=self._connectionClass,
-                               jobArgs=(self,), **kw)
+                               jobArgs=(self, timeout), **kw)
 
         try:
             import resource
@@ -123,8 +132,7 @@ class WSGIServer(BaseFCGIServer, PreforkServer):
         """
         self._web_server_addrs = os.environ.get('FCGI_WEB_SERVER_ADDRS')
         if self._web_server_addrs is not None:
-            self._web_server_addrs = map(lambda x: x.strip(),
-                                         self._web_server_addrs.split(','))
+            self._web_server_addrs = [x.strip() for x in self._web_server_addrs.split(',')]
 
         sock = self._setupSocket()
 
@@ -134,24 +142,20 @@ class WSGIServer(BaseFCGIServer, PreforkServer):
 
         return ret
 
-def factory(global_conf, host=None, port=None, **local):
-    import paste_factory
-    return paste_factory.helper(WSGIServer, global_conf, host, port, **local)
-
 if __name__ == '__main__':
     def test_app(environ, start_response):
         """Probably not the most efficient example."""
-        import cgi
+        from . import cgi
         start_response('200 OK', [('Content-Type', 'text/html')])
         yield '<html><head><title>Hello World!</title></head>\n' \
               '<body>\n' \
               '<p>Hello World!</p>\n' \
               '<table border="1">'
-        names = environ.keys()
+        names = list(environ.keys())
         names.sort()
         for name in names:
             yield '<tr><td>%s</td><td>%s</td></tr>\n' % (
-                name, cgi.escape(`environ[name]`))
+                name, cgi.escape(repr(environ[name])))
 
         form = cgi.FieldStorage(fp=environ['wsgi.input'], environ=environ,
                                 keep_blank_values=1)
